@@ -14,7 +14,7 @@ def getOptionVal(options, key):
 def main():
     try:
         opts, args = getopt.gnu_getopt(sys.argv[1:], 'm:hvi:c:su:l:', [
-            'mode=', 'help', 'version', 'img_service=', 'change_token=', 'scan', 'des_dir=','url_encode=','language='])
+            'mode=', 'help', 'version', 'img_service=', 'change_token=', 'scan', 'des_dir=', 'url_encode=', 'language=', 'compress', 'debug='])
     except getopt.GetoptError as e:
         print("获取参数信息出错，错误提示：", e.msg)
         exit()
@@ -51,10 +51,15 @@ def main():
             elif argKey == '--scan' or argKey == '-s':
                 mainProcess.scanAndCreateIndex()
             elif argKey == '--url_encode' or argKey == '-u':
-                params = {'url_encode_mode':argVal}
+                params = {'url_encode_mode': argVal}
                 mainProcess.changeMainPrams(params)
             elif argKey == '--language' or argKey == '-l':
-                params = {'language':argVal}
+                params = {'language': argVal}
+                mainProcess.changeMainPrams(params)
+            elif argKey == '--compress':
+                mainProcess.inputCompressInfo()
+            elif argKey == '--debug':
+                params = {'debug': argVal}
                 mainProcess.changeMainPrams(params)
             else:
                 mainProcess.main()
